@@ -19,6 +19,8 @@
 #' @param pointsize	shape size
 #' @param linesize	line size
 #' @param pointshape format point (default is 21)
+#' @param colorline Color lines
+#' @param fillshape Fill shape
 #' @param round round equation
 #' @param xname.formula Name of x in the equation
 #' @param yname.formula Name of y in the equation
@@ -80,6 +82,8 @@ plateau.quadratic=function(trat,resp,
                            pointsize = 4.5,
                            linesize = 0.8,
                            pointshape = 21,
+                           fillshape = "gray",
+                           colorline = "black",
                            round=NA,
                            yname.formula="y",
                            xname.formula="x",
@@ -124,7 +128,7 @@ plateau.quadratic=function(trat,resp,
     b=round(coef(mod)[3],round)
     c=round(coef(mod)[4],round)}
 
-  s <- sprintf("~~~%s == %e %s %e * %s %s %e * %s^2~(%s>%e) ~~~~~ italic(R^2) ==  %0.2f",
+  s <- sprintf("~~~%s == %e %s %e * %s %s %e * %s^2~(%s~'>'~%e) ~~~~~ italic(R^2) ==  %0.2f",
                yname.formula,
                a,
                ifelse(b >= 0, "+", "-"),
@@ -151,11 +155,11 @@ plateau.quadratic=function(trat,resp,
                                                  width=width.bar,
                                                  size=linesize)}
     graph=graph+
-      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
     graph=ggplot(data.frame(trat,resp),aes(x=trat,y=resp))
     graph=graph+
-      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   xp=seq(min(trat),max(trat),length=sample.curve)
   yp=predict(mod,newdata=data.frame(trat=xp))
   preditos=data.frame(x=xp,y=yp)
@@ -167,7 +171,7 @@ plateau.quadratic=function(trat,resp,
     geom_line(data=preditos,aes(x=x,
                                 y=y,
                                 color="black"),size=linesize)+
-    scale_color_manual(name="",values="black",label=parse(text = equation))+
+    scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
           legend.position = legend.position,
